@@ -8,7 +8,7 @@ import m3u8
 import shutil
 
 import crypto
-from futures import ThreadPoolExecutor
+from futures import ThreadPoolExecutor, TimeoutError
 
 import helpers
 import atomic
@@ -17,6 +17,7 @@ from transcode import transcode_playlist
 config = helpers.load_config()
 NUM_THREAD_WORKERS = config.getint('hlsclient', 'num_thread_workers')
 DOWNLOAD_TIMEOUT = config.getint('hlsclient', 'download_timeout')
+CONSUME_TIMEOUT = config.getint('hlsclient', 'consume_timeout')
 
 def consume_from_balancer(balancer, playlists, destination, encrypt=False):
     '''
@@ -33,17 +34,20 @@ def consume_from_balancer(balancer, playlists, destination, encrypt=False):
             segments_modified = consume(m3u8_uri, destination, encrypt)
         except (httplib.HTTPException, urllib2.HTTPError, IOError, OSError) as err:
             logging.warning(u'Notifying error for resource %s: %s' % (m3u8_uri, err))
-            balancer.notify_error(playlist_resource.server, playlist_resource.key)
+            balancer.notify_error()
         else:
             if segments_modified:
                 logging.info('Notifying content modified: %s' % m3u8_uri)
-                balancer.notify_modified(playlist_resource.server, playlist_resource.key)
+                balancer.notify_modified()
                 m3u8_path = os.path.join(build_full_path(destination, m3u8_uri), os.path.basename(m3u8_uri))
                 transcode_playlist(playlists, playlist_resource.key, segments_modified, m3u8_path)
             else:
                 logging.debug('Content not modified: %s' % m3u8_uri)
-    with ThreadPoolExecutor(max_workers=NUM_THREAD_WORKERS) as executor:
-        list(executor.map(consume_resource, balancer.actives))
+    try:
+        with ThreadPoolExecutor(max_workers=NUM_THREAD_WORKERS) as executor:
+            list(executor.map(consume_resource, balancer.actives, timeout=CONSUME_TIMEOUT))
+    except TimeoutError:
+        balancer.notify_error()
 
 def consume(m3u8_uri, destination_path, encrypt=False):
     '''
@@ -129,7 +133,7 @@ def download_segments(playlist, destination_path, new_key):
             raise
 
     with ThreadPoolExecutor(max_workers=NUM_THREAD_WORKERS) as executor:
-        downloads = executor.map(download, uris)
+        downloads = executor.map(download, uris, timeout=CONSUME_TIMEOUT)
         return list(downloads)
 
 def save_m3u8(playlist, m3u8_uri, full_path, new_key=False):
