@@ -7,7 +7,7 @@ from lockfile.linklockfile import LinkLockFile
 class ExpiringLinkLockFile(LinkLockFile):
     def __init__(self, *args, **kwargs):
         LinkLockFile.__init__(self, *args, **kwargs)
-        self.unique_name = "{original_name}_{base_path}_{random}".format(
+        self.unique_name = "{original_name}_{base_path}_{random}.lock".format(
             original_name=self.unique_name,
             base_path=os.path.basename(self.path),
             random="%0x" % random.randint(0, 2**64))
